import os
import sys

CURRENT_DIR = os.path.dirname(__file__)
ROOT_DIR = os.path.dirname(CURRENT_DIR)
PROJECT_DIR = os.path.join(CURRENT_DIR, 'project')
sys.path.insert(0, ROOT_DIR)
sys.path.insert(0, PROJECT_DIR)

os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'project.settings')

import django
from django.test import RequestFactory, override_settings

django.setup()

from xldashboard.templatetags.xl_dashboard_tags import show_xl_dashboard


def _dummy_user():
    class DummyUser:
        is_authenticated = True
    return DummyUser()


def test_show_xl_dashboard_uses_settings_order_and_names():
    rf = RequestFactory()
    request = rf.get('/')
    request.user = _dummy_user()

    dashboard = {
        'Events': {
            'Profiles': '/profiles/',
            'Events': '/events/',
            'Demo keys': '/demo/',
            'Host keys': '/host/',
        }
    }

    side_menu_list = [
        {
            'name': 'Wrong',
            'models': [
                {'name': 'Bad1', 'url': '/bad1/'},
                {'name': 'Bad2', 'url': '/bad2/'},
            ],
        }
    ]

    with override_settings(XL_DASHBOARD=dashboard):
        result = show_xl_dashboard({'request': request}, side_menu_list)

    assert [sec[0] for sec in result['sections']] == ['Events']
    assert [name for name, _ in result['sections'][0][1]] == [
        'Profiles',
        'Events',
        'Demo keys',
        'Host keys',
    ]


def test_show_xl_dashboard_preserves_multiple_section_order():
    rf = RequestFactory()
    request = rf.get('/')
    request.user = _dummy_user()

    dashboard = {
        'General': {
            'Users': '/users/',
            'Social links': '/social-links/',
        },
        'Events': {
            'Profiles': '/profiles/',
            'Events': '/events/',
        },
    }

    with override_settings(XL_DASHBOARD=dashboard):
        result = show_xl_dashboard({'request': request}, [])

    assert [sec[0] for sec in result['sections']] == ['General', 'Events']
    assert [name for name, _ in result['sections'][0][1]] == ['Users', 'Social links']
    assert [name for name, _ in result['sections'][1][1]] == ['Profiles', 'Events']


def test_show_xl_dashboard_uses_custom_names_for_model_paths():
    rf = RequestFactory()
    request = rf.get('/')
    request.user = _dummy_user()

    dashboard = {
        'General': {
            'Account users': 'app.User',
        }
    }

    with override_settings(XL_DASHBOARD=dashboard):
        result = show_xl_dashboard({'request': request}, [])

    assert result['sections'][0][1][0][0] == 'Account users'



JAZZMIN_SETTINGS = {
    'site_title': 'xlartas',
    'site_header': 'xlartas',
    'site_brand': 'xlartas',
    'site_logo': '/img/icon/logo.png',
    'site_logo_classes': '',
    'site_icon': '/img/icon/logo.png',
    'login_logo': '/img/icon/logo.png',
    'login_logo_dark': '/img/icon/logo.png',
    'welcome_sign': '',
    'copyright': 'xlartas © 2025',
    'show_sidebar': True,
    'navigation_expanded': True,
    'hide_apps': [],
    'hide_models': [],
    'order_with_respect_to': ['core'],
    'user_avatar': 'avatar',
    'related_modal_active': True,
    'custom_css': '/admin/css/jazzmin.css',
    'custom_js': '/admin/js/jazzmin.js',
    'theme': 'darkly',
    'dark_mode_theme': 'darkly',
    'navbar_small_text': False,
    'footer_small_text': False,
    'body_small_text': True,
    'brand_small_text': False,
    'brand_colour': 'navbar-dark',
    'accent': 'accent-lightblue',
    'navbar': 'navbar-dark',
    'no_navbar_border': False,
    'navbar_fixed': True,
    'layout_boxed': False,
    'footer_fixed': False,
    'sidebar_fixed': True,
    'sidebar': 'sidebar-dark-indigo',
    'sidebar_nav_small_text': False,
    'sidebar_disable_expand': True,
    'sidebar_nav_child_indent': False,
    'sidebar_nav_compact_style': False,
    'sidebar_nav_legacy_style': False,
    'sidebar_nav_flat_style': False,
    'button_classes': {
        'primary': 'btn-primary',
        'secondary': 'btn-secondary',
        'info': 'btn-info',
        'warning': 'btn-warning',
        'danger': 'btn-danger',
        'success': 'btn-success',
    },
    'actions_sticky_top': True,
    'usermenu_links': [
        {'name': 'Site', 'url': '', 'new_window': True},
        {'name': 'Logs', 'url': '', 'new_window': True},
        {'name': 'Swagger', 'url': '', 'new_window': True},
    ],
}

JAZZMIN_UI_TWEAKS = {
    'theme': 'darkly',
    'dark_mode_theme': 'darkly',
    'navbar': 'navbar-dark',
    'accent': 'accent-lightblue',
    'navbar_small_text': False,
    'sidebar': 'sidebar-dark-indigo',
    'sidebar_nav_small_text': False,
    'sidebar_disable_expand': True,
    'sidebar_nav_child_indent': False,
    'sidebar_nav_compact_style': True,
    'footer_fixed': False,
    'navbar_fixed': True,
    'actions_sticky_top': True,
}
